@@ -16,7 +16,7 @@ from pathlib import Path
 from typing import cast, Any, AnyStr, Dict, Optional, IO, Iterator, \
     List, MutableMapping, Union, Tuple
 from urllib.request import urlopen
-from urllib.parse import urlsplit
+from urllib.parse import urlsplit, unquote
 from urllib.error import URLError
 
 from elementpath import XPathToken, XPathContext, XPath2Parser, ElementNode, \
@@ -280,7 +280,7 @@ class XMLResource:
         """
         The source name, is `None` if the instance is created from an Element or a string.
         """
-        return None if self._url is None else os.path.basename(self._url)
+        return None if self._url is None else os.path.basename(unquote(self._url))
 
     @property
     def url(self) -> Optional[str]:
@@ -751,12 +751,12 @@ class XMLResource:
     def get_absolute_path(self, path: Optional[str] = None) -> str:
         if path is None:
             if self._lazy:
-                return '/%s/%s' % (self._root.tag, '/'.join('*' * int(self._lazy)))
-            return '/%s' % self._root.tag
+                return f"/{self._root.tag}/{'/'.join('*' * int(self._lazy))}"
+            return f'/{self._root.tag}'
         elif path.startswith('/'):
             return path
         else:
-            return '/%s/%s' % (self._root.tag, path)
+            return f'/{self._root.tag}/{path}'
 
     def get_text(self) -> str:
         """
@@ -992,7 +992,7 @@ class XMLResource:
         :param ancestors: provide a list for tracking the ancestors of yielded elements.
         """
         if mode not in (1, 2, 3, 4, 5):
-            raise XMLSchemaValueError("invalid argument mode={!r}".format(mode))
+            raise XMLSchemaValueError(f"invalid argument mode={mode!r}")
 
         if ancestors is not None:
             ancestors.clear()
@@ -1091,7 +1091,7 @@ class XMLResource:
         level = 0
 
         path = path.replace(' ', '').replace('./', '')
-        select_all = '*' in path and set(path).issubset({'*', '/'})
+        select_all = '*' in path and set(path).issubset(('*', '/'))
         if path == '.':
             path_depth = 0
         elif path.startswith('/'):
